c     ******************************************************************
c     Jacquemoud S., Ustin S.L., Verdebout J., Schmuck G., Andreoli G.,
c     Hosgood B. (1995), PROSPECT return, Remote Sens, Environ., in
c     preparation.
c     Jacquemoud S., Baret F. (1990), PROSPECT: a model of leaf optical
c     properties spectra, Remote Sens. Environ., 34:75-91.
c     ******************************************************************
c     Stephane JACQUEMOUD
c     University of California, Davis
c     Department of Land, Air, and Water Resources
c     Davis, CA 95616
c     USA
c     tel: (1)-916-752-5092
c     fax: (1)-916-752-5262
c     E-mail: stephane@vache.ucdavis.edu
c     Mosaic: http://vaca.ucdavis.edu/staff/stephane/index.html
c     version 2.01 (10 April 1995)
c     ******************************************************************

      subroutine leaftwo(main_r,main_t,vai,cab,cw,cp,cc)

      double precision n,k
      double precision vai,cab,cw,cp,cc
      double precision main_r(2500),main_t(2500)
      double precision long(421),refra(421),ke(421)
      double precision kab(421),kw(421),kp(421),kc(421)

      common /leafin/n,k
c     common /leafout/refl,tran
      common /wave/long
      common /dat/refra,ke,kab,kw,kp,kc

      call valeur

c	open(37, file='params.tmp',form='formatted')
c	rewind (37)
c	do 1 line = 1,1
c		read(37,*, ERR=1, END=1 )vai,cab,cw,cp,cc
c			print *,vai,cab,cw,cp,cc
c 1	continue
c	close (37)

	
c	**********************************************************


c      open (1,file='leaf',form='formatted',status='unknown')

      do 10 i=1,421

        n=refra(i)
        k=ke(i)+(cab*kab(i)+cw*kw(i)+cp*kp(i)+cc*kc(i))/vai
        call leaf(main_r,main_t,vai,i)
c       write (*,20) long(i),refl,tran
c       write (1,20) long(i),refl,tran
c 20      format(2x,f6.1,2(2x,f6.4))

10    continue
      close (1)

c     stop
      end

      subroutine leaf(main_r,main_t,vai,i)

      double precision n,k,vai
      double precision refl,main_r(2500),main_t(2500),tran
      double precision inex
      double precision teta,tau
      double precision t1,t2,x1,x2,x3,x4,x5,x6,r,t,ra,ta
      double precision delta,alfa,beta,va,vb,s1,s2,s3

      intrinsic sqrt,exp

      common /leafin/n,k
      common /leafout/refl,tran
      common /nagout/inex
      common /tauin/teta
      common /tauout/tau

c     ******************************************************************
c     reflectance and transmittance of one layer
c     ******************************************************************
c     Allen W.A., Gausman H.W., Richardson A.J., Thomas J.R. (1969),
c     Interaction of isotropic ligth with a compact plant leaf, J. Opt.
c     Soc. Am., 59(10):1376-1379.
c     Jacquemoud S., Baret F. (1990), Prospect: a model of leaf optical
c     properties spectra, Remote Sens. Environ., 34:75-91.
c     ******************************************************************

      if (k.le.0.) then
        k=1.
      else
        call s13aaf
        k=(1.-k)*dexp(-k)+k**2*inex
      endif

      teta=90.
      call tav
      t1=tau
      teta=60.
      call tav
      t2=tau
      x1=1.-t1
      x2=t1**2*k**2*(n**2-t1)
      x3=t1**2*k*n**2
      x4=n**4-k**2*(n**2-t1)**2
      x5=t2/t1
      x6=x5*(t1-1.)+1.-t2
      r=x1+x2/x4
      t=x3/x4
      ra=x5*r+x6
      ta=x5*t

c     ******************************************************************
c     reflectance and transmittance of N layers
c     ******************************************************************
c     Stokes G.G. (1862), On the intensity of the light reflected from
c     or transmitted through a pile of plates, Proc. Roy. Soc. Lond.,
c     11:545-556.
c     ******************************************************************

      delta=(t**2-r**2-1.)**2-4.*r**2
      alfa=(1.+r**2-t**2+dsqrt(delta))/(2.*r)
      beta=(1.+r**2-t**2-dsqrt(delta))/(2.*r)
      va=(1.+r**2-t**2+dsqrt(delta))/(2.*r)
      vb=dsqrt(beta*(alfa-r)/(alfa*(beta-r)))
      s1=ra*(va*vb**(vai-1.)-va**(-1.)*vb**(-(vai-1.)))
     &   +(ta*t-ra*r)*(vb**(vai-1.)-vb**(-(vai-1.)))
      s2=ta*(va-va**(-1.))
      s3=va*vb**(vai-1.)-va**(-1.)*vb**(-(vai-1.))
     &   -r*(vb**(vai-1.)-vb**(-(vai-1.)))
      refl=s1/s3
      tran=s2/s3
      main_r(i)=refl
      main_t(i)=tran
      return
      end

c     ******************************************************************
c     exponential integral: int(exp(-t)/t,t=x..inf)
c     ******************************************************************

      subroutine s13aaf()

      double precision n,k
      double precision inex,x,y

      intrinsic log,exp

      common /leafin/n,k
      common /nagout/inex

      if (k.gt.4.) goto 10

      x=0.5*k-1.
      y=(((((((((((((((-3.60311230482612224d-13
     &  *x+3.46348526554087424d-12)*x-2.99627399604128973d-11)
     &  *x+2.57747807106988589d-10)*x-2.09330568435488303d-9)
     &  *x+1.59501329936987818d-8)*x-1.13717900285428895d-7)
     &  *x+7.55292885309152956d-7)*x-4.64980751480619431d-6)
     &  *x+2.63830365675408129d-5)*x-1.37089870978830576d-4)
     &  *x+6.47686503728103400d-4)*x-2.76060141343627983d-3)
     &  *x+1.05306034687449505d-2)*x-3.57191348753631956d-2)
     &  *x+1.07774527938978692d-1)*x-2.96997075145080963d-1
      y=(y*x+8.64664716763387311d-1)*x+7.42047691268006429d-1
      inex=y-dlog(k)
      goto 30

10    if (k.ge.85.) goto 20
      x=14.5/(k+3.25)-1.
      y=(((((((((((((((-1.62806570868460749d-12
     &  *x-8.95400579318284288d-13)*x-4.08352702838151578d-12)
     &  *x-1.45132988248537498d-11)*x-8.35086918940757852d-11)
     &  *x-2.13638678953766289d-10)*x-1.10302431467069770d-9)
     &  *x-3.67128915633455484d-9)*x-1.66980544304104726d-8)
     &  *x-6.11774386401295125d-8)*x-2.70306163610271497d-7)
     &  *x-1.05565006992891261d-6)*x-4.72090467203711484d-6)
     &  *x-1.95076375089955937d-5)*x-9.16450482931221453d-5)
     &  *x-4.05892130452128677d-4)*x-2.14213055000334718d-3
      y=((y*x-1.06374875116569657d-2)*x-8.50699154984571871d-2)*x
     &  +9.23755307807784058d-1
      inex=dexp(-k)*y/k
      goto 30

20    inex=0.
      goto 30

30    continue

      return
      end

c     ******************************************************************
c     evaluation of tav for any solid angle
c     ******************************************************************
c     Stern F. (1964), Transmission of isotropic radiation across an
c     interface between two dielectrics, Appl. Opt., 3(1):111-113.
c     Allen W.A. (1973), Transmission of isotropic light across a
c     dielectric surface in two and three dimensions, J. Opt. Soc. Am.,
c     63(6):664-666.
c     ******************************************************************

      subroutine tav()

      double precision pi,rd
      double precision n,k
      double precision teta,tau
      double precision r2,rp,rm,a,b,ds
      double precision b0,b1,b2,ts,tp1,tp2,tp3,tp4,tp5,tp

      intrinsic sqrt,log,sin

      common /leafin/n,k
      common /tauin/teta
      common /tauout/tau

      pi=dacos(0.d+0)*2.
      rd=pi/180.

      teta=teta*rd
      r2=n**2
      rp=r2+1.
      rm=r2-1.
      a=(n+1.)**2/2.
      b=-(r2-1.)**2/4.
      ds=dsin(teta)

      if (teta.eq.0.) then
        tau=4.*n/(n+1.)**2
      else
        if (teta.eq.pi/2.) then
          b1=0.
        else
          b1=dsqrt((ds**2-rp/2.)**2+b)
        endif
        b2=ds**2-rp/2.
        b0=b1-b2
        ts=(b**2/(6.*b0**3)+b/b0-b0/2.)-(b**2/(6.*a**3)+b/a-a/2.)
        tp1=-2.*r2*(b0-a)/rp**2
        tp2=-2.*r2*rp*dlog(b0/a)/rm**2
        tp3=r2*(1./b0-1./a)/2.
        tp4=16.*r2**2*(r2**2+1.)*dlog((2.*rp*b0-rm**2)/(2.*rp*a-rm**2))
     &      /(rp**3*rm**2)
        tp5=16.*r2**3*(1./(2.*rp*b0-rm**2)-1./(2.*rp*a-rm**2))/rp**3
        tp=tp1+tp2+tp3+tp4+tp5
        tau=(ts+tp)/(2.*ds**2)
      endif

      return
      end

c     ******************************************************************
c     wavelength (long), refractive index (refra), absorption
c     coefficient of an albino leaf (ke), specific absorption
c     coefficient of chlorophyll a+b (kab), water (kw), protein (kp),
c     and cellulose+lignin (kc)
c     ******************************************************************
c     Jacquemoud S., Ustin S.L., Verdebout J., Schmuck G., Andreoli G.,
c     Hosgood B. (1995), PROSPECT return, in preparation.
c     ******************************************************************

      subroutine valeur()

      double precision long(421),refra(421),ke(421),kab(421),kw(421),
     & kp(421),kc(421)
      double precision long0(421),refra0(421),ke0(421),kab0(421),
     & kw0(421),kp0(421),kc0(421)

      common /wave/long
      common /dat/refra,ke,kab,kw,kp,kc

      data (long0(i),i=1,105)/
     & 400,405,410,415,420,425,430,435,440,445,450,455,460,465,470,475,
     & 480,485,490,495,500,505,510,515,520,525,530,535,540,545,550,555,
     & 560,565,570,575,580,585,590,595,600,605,610,615,620,625,630,635,
     & 640,645,650,655,660,665,670,675,680,685,690,695,700,705,710,715,
     & 720,725,730,735,740,745,750,755,760,765,770,775,780,785,790,795,
     & 800,805,810,815,820,825,830,835,840,845,850,855,860,865,870,875,
     & 880,885,890,895,900,905,910,915,920/
       data (long0(i),i=106,210)/
     & 925,930,935,940,945,950,955,960,965,970,975,980,985,990,995,
     & 1000,1005,1010,1015,1020,1025,1030,1035,1040,1045,1050,1055,1060,
     & 1065,1070,1075,1080,1085,1090,1095,1100,1105,1110,1115,1120,1125,
     & 1130,1135,1140,1145,1150,1155,1160,1165,1170,1175,1180,1185,1190,
     & 1195,1200,1205,1210,1215,1220,1225,1230,1235,1240,1245,1250,1255,
     & 1260,1265,1270,1275,1280,1285,1290,1295,1300,1305,1310,1315,1320,
     & 1325,1330,1335,1340,1345,1350,1355,1360,1365,1370,1375,1380,1385,
     & 1390,1395,1400,1405,1410,1415,1420,1425,1430,1435,1440,1445/
       data (long0(i),i=211,315)/
     & 1450,1455,1460,1465,1470,1475,1480,1485,1490,1495,1500,1505,1510,
     & 1515,1520,1525,1530,1535,1540,1545,1550,1555,1560,1565,1570,1575,
     & 1580,1585,1590,1595,1600,1605,1610,1615,1620,1625,1630,1635,1640,
     & 1645,1650,1655,1660,1665,1670,1675,1680,1685,1690,1695,1700,1705,
     & 1710,1715,1720,1725,1730,1735,1740,1745,1750,1755,1760,1765,1770,
     & 1775,1780,1785,1790,1795,1800,1805,1810,1815,1820,1825,1830,1835,
     & 1840,1845,1850,1855,1860,1865,1870,1875,1880,1885,1890,1895,1900,
     & 1905,1910,1915,1920,1925,1930,1935,1940,1945,1950,1955,1960,1965,
     & 1970/
       data (long0(i),i=316,421)/
     & 1975,1980,1985,1990,1995,2000,2005,2010,2015,2020,2025,2030,2035,
     & 2040,2045,2050,2055,2060,2065,2070,2075,2080,2085,2090,2095,2100,
     & 2105,2110,2115,2120,2125,2130,2135,2140,2145,2150,2155,2160,2165,
     & 2170,2175,2180,2185,2190,2195,2200,2205,2210,2215,2220,2225,2230,
     & 2235,2240,2245,2250,2255,2260,2265,2270,2275,2280,2285,2290,2295,
     & 2300,2305,2310,2315,2320,2325,2330,2335,2340,2345,2350,2355,2360,
     & 2365,2370,2375,2380,2385,2390,2395,2400,2405,2410,2415,2420,2425,
     & 2430,2435,2440,2445,2450,2455,2460,2465,2470,2475,2480,2485,2490,
     & 2495,2500/

      data (refra0(i),i=1,105)/
     & 1.512,1.512,1.508,1.506,1.503,1.502,1.500,1.499,1.498,1.497,
     & 1.496,1.495,1.494,1.493,1.492,1.492,1.491,1.490,1.490,1.489,
     & 1.488,1.487,1.486,1.485,1.484,1.482,1.481,1.479,1.477,1.476,
     & 1.474,1.472,1.470,1.468,1.466,1.464,1.462,1.461,1.459,1.457,
     & 1.456,1.455,1.453,1.452,1.451,1.450,1.449,1.449,1.448,1.448,
     & 1.447,1.447,1.447,1.447,1.446,1.446,1.446,1.446,1.445,1.445,
     & 1.444,1.444,1.443,1.443,1.442,1.441,1.440,1.439,1.438,1.437,
     & 1.437,1.436,1.435,1.435,1.434,1.434,1.434,1.434,1.434,1.434,
     & 1.435,1.435,1.435,1.435,1.435,1.435,1.435,1.435,1.435,1.435,
     & 1.435,1.435,1.435,1.435,1.435,1.434,1.434,1.434,1.434,1.434,
     & 1.434,1.434,1.433,1.433,1.433/
      data (refra0(i),i=106,210)/
     & 1.433,1.433,1.432,1.432,1.432,1.432,1.432,1.431,1.431,1.431,
     & 1.431,1.430,1.430,1.430,1.429,1.429,1.428,1.428,1.427,1.427,
     & 1.427,1.426,1.426,1.425,1.425,1.424,1.424,1.423,1.422,1.422,
     & 1.421,1.421,1.420,1.420,1.419,1.418,1.418,1.417,1.417,1.416,
     & 1.415,1.415,1.414,1.414,1.413,1.413,1.412,1.412,1.411,1.410,
     & 1.410,1.409,1.409,1.408,1.408,1.407,1.407,1.406,1.406,1.405,
     & 1.405,1.404,1.404,1.403,1.403,1.402,1.402,1.401,1.401,1.400,
     & 1.399,1.399,1.398,1.398,1.397,1.397,1.396,1.396,1.395,1.395,
     & 1.394,1.394,1.393,1.393,1.392,1.392,1.391,1.391,1.390,1.390,
     & 1.389,1.389,1.388,1.388,1.387,1.387,1.386,1.385,1.385,1.384,
     & 1.384,1.383,1.382,1.382,1.381/
      data (refra0(i),i=211,315)/
     & 1.380,1.380,1.379,1.378,1.377,1.377,1.376,1.375,1.374,1.373,
     & 1.373,1.372,1.371,1.370,1.369,1.369,1.368,1.367,1.366,1.365,
     & 1.365,1.364,1.363,1.362,1.361,1.360,1.360,1.359,1.358,1.357,
     & 1.356,1.356,1.355,1.354,1.353,1.352,1.352,1.351,1.350,1.349,
     & 1.348,1.348,1.347,1.346,1.345,1.345,1.344,1.343,1.343,1.342,
     & 1.341,1.341,1.340,1.339,1.339,1.338,1.337,1.337,1.336,1.336,
     & 1.335,1.335,1.334,1.334,1.333,1.333,1.332,1.332,1.331,1.331,
     & 1.331,1.330,1.330,1.329,1.329,1.329,1.328,1.328,1.327,1.327,
     & 1.327,1.326,1.326,1.326,1.325,1.325,1.325,1.324,1.324,1.323,
     & 1.323,1.323,1.323,1.322,1.322,1.322,1.321,1.321,1.320,1.320,
     & 1.320,1.320,1.319,1.319,1.318/
      data (refra0(i),i=316,421)/
     & 1.318,1.318,1.317,1.317,1.317,1.316,1.316,1.315,1.315,1.314,
     & 1.314,1.313,1.313,1.312,1.312,1.311,1.311,1.310,1.310,1.309,
     & 1.309,1.308,1.307,1.307,1.306,1.306,1.305,1.305,1.304,1.303,
     & 1.303,1.302,1.302,1.301,1.300,1.300,1.299,1.299,1.298,1.297,
     & 1.297,1.296,1.296,1.295,1.294,1.294,1.293,1.292,1.292,1.291,
     & 1.291,1.290,1.289,1.289,1.288,1.288,1.287,1.287,1.286,1.285,
     & 1.285,1.284,1.284,1.283,1.283,1.282,1.282,1.281,1.281,1.280,
     & 1.280,1.279,1.279,1.279,1.278,1.278,1.277,1.277,1.276,1.276,
     & 1.276,1.275,1.275,1.274,1.274,1.274,1.273,1.273,1.273,1.273,
     & 1.272,1.272,1.272,1.272,1.271,1.271,1.271,1.271,1.271,1.271,
     & 1.271,1.271,1.271,1.272,1.273,1.274/

      data ke0/
     & 0.1162,0.0977,0.0715,0.0494,0.0345,0.0228,0.0151,0.0098,0.0093,
     & 0.0058,0.0026,0.0030,0.0000,0.0006,0.0008,0.0006,0.0008,404*0./

      data kab0/
     & 0.0725,0.0669,0.0615,0.0573,0.0549,0.0528,0.0521,0.0515,0.0504,
     & 0.0488,0.0460,0.0438,0.0429,0.0429,0.0424,0.0420,0.0415,0.0408,
     & 0.0394,0.0373,0.0342,0.0303,0.0261,0.0218,0.0180,0.0151,0.0133,
     & 0.0124,0.0120,0.0117,0.0115,0.0116,0.0120,0.0127,0.0140,0.0153,
     & 0.0165,0.0174,0.0181,0.0186,0.0189,0.0194,0.0204,0.0215,0.0225,
     & 0.0230,0.0232,0.0236,0.0249,0.0270,0.0289,0.0301,0.0322,0.0356,
     & 0.0384,0.0399,0.0398,0.0363,0.0277,0.0187,0.0124,0.0085,0.0060,
     & 0.0043,0.0030,0.0020,0.0014,0.0009,0.0006,0.0004,0.0002,0.0002,
     & 0.0001,0.0001,0.0001,346*0./

      data (kw0(i),i=1,105)/80*0.,
     & 0.01,0.02,0.02,0.03,0.03,0.03,0.03,0.04,0.04,0.04,0.04,0.04,0.04,
     & 0.05,0.05,0.05,0.06,0.06,0.06,0.07,0.07,0.08,0.08,0.09,0.11/
      data (kw0(i),i=106,210)/
     & 0.15,0.19,0.25,0.31,0.36,0.40,0.42,0.45,0.45,0.46,0.46,0.43,0.41,
     & 0.40,0.38,0.36,0.33,0.30,0.25,0.20,0.19,0.19,0.17,0.16,0.15,0.15,
     & 0.14,0.13,0.13,0.13,0.14,0.14,0.15,0.16,0.18,0.20,0.23,0.27,0.32,
     & 0.37,0.45,0.53,0.64,0.74,0.96,1.16,1.31,1.36,1.42,1.44,1.44,1.46,
     & 1.50,1.52,1.51,1.51,1.51,1.48,1.49,1.47,1.46,1.44,1.43,1.41,1.39,
     & 1.38,1.38,1.36,1.36,1.37,1.40,1.41,1.45,1.49,1.59,1.67,1.78,1.90,
     & 2.07,2.25,2.47,2.71,2.95,3.24,3.46,3.69,3.91,4.12,4.41,4.84,5.53,
     & 6.58,8.24,10.57,13.53,16.87,20.01,23.02,25.29,27.25,29.10,30.04,
     & 30.93,31.77,32.55/
      data (kw0(i),i=211,315)/
     & 31.82,32.04,32.23,31.41,30.00,28.81,27.21,26.10,24.83,23.47,
     & 22.08,20.81,19.61,18.50,17.58,16.60,15.62,14.90,14.15,13.50,
     & 12.85,12.23,11.71,11.18,10.74,10.37,9.95,9.62,9.33,9.06,8.81,
     & 8.59,8.40,8.20,8.03,7.88,7.73,7.63,7.49,7.35,7.30,7.22,7.11,
     & 7.08,7.02,6.92,6.87,6.86,6.85,6.85,6.89,6.94,7.02,7.10,7.22,
     & 7.34,7.57,7.79,8.05,8.35,8.65,8.97,9.33,9.67,9.96,10.17,10.38,
     & 10.52,10.58,10.58,10.60,10.53,10.54,10.53,10.55,10.65,10.75,
     & 10.96,11.29,11.84,12.64,13.86,15.48,17.89,21.82,27.85,35.91,
     & 48.60,63.25,75.92,92.99,110.69,126.52,136.96,140.97,143.63,
     & 145.60,144.89,139.68,141.07,135.45,132.72,127.03,124.46,117.76/
      data (kw0(i),i=316,421)/
     & 106.83,100.20,94.80,89.02,84.88,80.60,77.01,72.90,70.31,67.31,
     & 64.87,61.65,59.63,57.65,55.51,53.30,51.62,49.96,46.48,42.66,
     & 40.36,38.70,37.45,35.45,33.88,32.76,31.26,30.05,29.03,27.84,
     & 27.14,26.36,25.34,24.76,24.28,23.63,23.04,22.66,22.31,22.06,
     & 21.89,21.56,21.37,21.16,20.97,20.87,20.88,20.69,20.77,20.45,
     & 20.64,20.63,20.76,20.92,21.27,21.39,21.62,21.79,22.19,22.46,
     & 22.99,23.52,24.15,24.83,25.07,25.63,26.74,27.66,28.27,29.54,
     & 31.00,31.71,33.03,34.66,35.28,36.95,38.48,41.15,41.15,42.44,
     & 45.28,51.36,53.18,53.95,55.87,56.02,59.44,60.56,61.08,62.79,
     & 66.82,66.61,69.05,70.29,73.60,79.39,79.43,81.30,86.35,90.36,
     & 93.10,93.29,93.47,109.13,112.55,113.00/

      data (kp0(i),i=1,105)/80*9.96,
     & 10.04,9.73,10.19,9.87,9.73,9.01,10.09,9.85,8.65,9.11,8.07,7.40,
     & 8.77,8.85,8.72,8.87,8.79,8.69,8.63,8.58,8.68,8.80,8.69,8.64,8.77/
      data (kp0(i),i=106,210)/
     & 8.49,8.43,8.15,8.02,7.89,7.96,7.88,7.69,7.71,7.52,7.64,7.55,7.48,
     & 7.36,7.72,7.51,7.47,7.27,7.28,7.36,7.39,7.54,7.58,7.78,7.84,7.81,
     & 7.49,7.63,7.63,7.57,7.68,7.49,7.54,7.32,7.41,7.28,7.37,7.26,7.25,
     & 7.25,6.91,7.03,7.14,7.07,7.01,7.01,7.25,6.87,7.17,7.16,7.27,7.07,
     & 7.29,7.22,6.86,6.83,7.06,6.91,6.93,6.94,6.79,6.59,6.54,6.52,6.39,
     & 6.38,6.35,6.05,5.93,6.21,6.33,6.19,6.22,6.06,6.32,6.34,6.19,6.26,
     & 6.24,6.18,6.15,6.07,6.06,6.28,6.05,6.18,6.53,6.33,5.92,6.16,6.33,
     & 6.51,6.35,6.52,6.58,6.55,6.66,7.05,7.07,6.85,7.51,7.70,7.94,8.38,
     & 8.88/
      data (kp0(i),i=211,315)/
     & 8.69,8.58,9.16,9.21,9.19,9.42,9.56,10.19,10.74,11.07,11.25,11.41,
     & 11.20,11.29,11.57,11.34,11.10,11.52,11.17,11.17,11.21,10.75,
     & 10.76,10.98,11.08,11.38,11.31,11.34,11.30,11.10,11.41,11.06,
     & 11.07,10.88,11.02,10.95,11.15,11.09,10.64,10.86,10.79,10.87,
     & 10.88,11.11,11.72,11.92,12.66,13.39,14.23,14.92,15.72,16.06,
     & 16.02,16.49,16.82,16.85,17.29,16.92,16.90,16.49,16.40,16.37,
     & 15.93,16.02,15.26,14.78,14.50,14.39,13.95,13.67,13.56,13.25,
     & 13.22,13.24,13.20,12.99,12.82,12.73,12.30,12.09,12.09,11.96,
     & 11.72,12.16,11.93,11.79,12.03,12.70,13.61,14.74,15.92,18.41,
     & 20.79,23.30,24.72,26.80,28.17,29.30,29.37,30.01,30.76,30.76,
     & 30.69,31.27,30.52/
      data (kp0(i),i=316,421)/
     & 30.91,31.00,30.63,30.06,30.42,30.29,30.12,29.99,29.48,30.47,
     & 30.99,31.99,33.47,35.76,38.29,40.32,42.19,43.24,42.73,41.77,
     & 40.65,39.60,39.80,39.35,39.43,39.80,39.74,40.20,40.52,40.31,
     & 40.98,41.63,42.63,43.65,45.62,46.64,47.78,48.69,49.74,50.40,
     & 50.63,50.44,49.54,49.41,49.09,48.32,48.11,46.97,46.28,44.85,
     & 44.19,43.54,43.98,45.09,46.77,49.10,51.89,54.67,57.54,60.58,
     & 62.71,64.36,66.40,68.31,69.16,69.97,70.75,70.29,69.39,68.70,
     & 68.25,67.35,67.80,67.79,67.76,68.42,67.33,67.34,65.99,65.00,
     & 63.89,64.05,63.20,62.69,63.11,61.07,64.01,64.00,63.79,63.86,
     & 66.18,65.85,67.72,69.09,71.18,75.81,76.40,79.19,80.45,80.71,
     & 79.90,77.83,80.85,82.27,80.66,78.93/

      data (kc0(i),i=1,105)/80*4.38,
     & 4.51,4.37,4.36,4.30,4.22,4.30,4.20,4.08,4.22,4.16,3.85,3.95,3.98,
     & 4.01,4.02,4.00,3.95,3.96,3.92,3.91,3.89,3.85,3.83,3.84,3.85/
      data (kc0(i),i=106,210)/
     & 3.77,3.76,3.80,3.82,3.85,3.85,3.84,3.88,3.86,3.89,3.89,3.90,3.89,
     & 3.86,3.83,3.81,3.79,3.75,3.78,3.73,3.69,3.64,3.58,3.62,3.63,3.55,
     & 3.51,3.49,3.44,3.50,3.46,3.39,3.41,3.43,3.49,3.46,3.43,3.36,3.40,
     & 3.43,3.44,3.47,3.54,3.53,3.54,3.64,3.71,3.77,3.87,3.91,4.07,4.24,
     & 4.36,4.48,4.48,4.47,4.54,4.58,4.57,4.53,4.15,4.09,3.99,3.93,3.87,
     & 3.82,3.82,3.80,3.80,3.76,3.72,3.71,3.63,3.53,3.52,3.51,3.47,3.47,
     & 3.43,3.44,3.44,3.41,3.50,3.60,3.69,3.89,4.06,4.21,4.35,4.70,4.74,
     & 4.79,4.83,4.96,5.01,5.22,5.44,6.04,6.74,7.76,8.85,9.74,10.53,
     & 10.95,11.30/
      data (kc0(i),i=211,315)/
     & 11.33,11.47,11.61,11.62,11.60,11.69,11.62,11.67,11.69,11.59,
     & 11.49,11.21,11.00,10.79,10.56,10.34,10.19,10.11,10.06,10.07,
     & 10.03,9.92,9.83,9.80,9.75,9.76,9.72,9.51,9.40,9.16,8.90,8.73,
     & 8.51,8.32,8.14,7.96,7.87,7.75,7.82,7.65,7.86,8.00,8.13,8.50,8.66,
     & 8.81,9.17,9.47,9.79,10.09,10.38,10.75,11.09,11.32,11.71,11.92,
     & 11.87,11.37,10.87,10.73,10.68,10.66,10.79,10.67,10.50,10.24,
     & 10.07,9.97,9.92,9.88,9.84,9.67,9.73,9.64,9.55,9.47,9.27,9.20,
     & 8.96,8.83,8.62,8.61,8.39,8.36,8.23,8.20,8.22,8.19,8.22,8.29,8.71,
     & 8.93,9.04,9.19,9.09,8.91,8.67,8.25,7.93,7.72,7.65,7.57,7.65,7.79,
     & 8.03/
      data (kc0(i),i=316,421)/
     & 8.14,8.30,8.53,8.82,9.16,9.71,10.41,11.31,12.44,13.74,15.37,
     & 16.99,18.73,20.62,22.35,24.12,25.73,27.07,28.39,29.48,30.48,
     & 31.20,31.75,32.21,32.73,33.10,33.21,33.26,33.27,33.16,32.96,
     & 32.62,32.16,31.72,31.07,30.36,29.66,28.94,28.21,27.57,27.10,
     & 26.63,26.14,25.71,25.24,24.84,24.79,24.58,24.63,24.60,25.24,
     & 26.15,27.54,29.45,31.81,34.32,36.53,38.29,40.09,41.25,42.00,
     & 42.59,43.12,43.73,44.50,46.03,47.31,48.01,47.88,47.88,47.82,
     & 47.77,48.23,48.65,48.27,47.98,47.65,47.36,45.90,45.51,45.19,
     & 45.21,45.08,44.07,43.96,42.98,43.83,43.80,43.86,44.48,46.27,
     & 46.57,48.58,49.63,52.52,55.55,57.69,59.09,62.39,64.37,67.35,
     & 66.18,67.90,70.75,68.61,68.20/

      do 10 i=1,421
        long(i)=long0(i)
        refra(i)=refra0(i)
        ke(i)=ke0(i)
        kab(i)=kab0(i)
        kw(i)=kw0(i)
        kp(i)=kp0(i)
        kc(i)=kc0(i)
10    continue

      return
      end
